==> evolver-script-java-0.1.0-sources.jar: fi/evolver/script/app/AwsSsoCli.java <==
package fi.evolver.script.app;

import java.io.IOException;
import java.net.URI;
import java.nio.file.Files;
import java.nio.file.Path;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;

import fi.evolver.script.FileUtils;
import fi.evolver.script.Shell;
import fi.evolver.script.Step;
import fi.evolver.script.system.Architecture;

public class AwsSsoCli {

	private static final URI AMD64_URL = URI.create("https://github.com/synfinatic/aws-sso-cli/releases/download/v2.0.0-beta4/aws-sso-cli_2.0.0-beta4-1_amd64.deb");
	private static final URI ARM64_URL = URI.create("https://github.com/synfinatic/aws-sso-cli/releases/download/v2.0.0-beta4/aws-sso-cli_2.0.0-beta4-1_arm64.deb");

	private static final Path AWS_DIR = Shell.HOME.resolve(".aws");
	private static final Path AWS_SSO_DIR = Shell.HOME.resolve(".aws-sso");

	private static final DateTimeFormatter BACKUP_DATETIME_FORMATTER = DateTimeFormatter.ofPattern("yyyyMMdd-HHmmss");

	public static void install() {
		try (Step step = Step.start("AWS SSO CLI: install")) {
			switch (Architecture.validated()) {
				case AMD64 -> Apt.installFromUrl(AMD64_URL);
				case ARM64 -> Apt.installFromUrl(ARM64_URL);
			}
			String completions = Shell.user("aws-sso", "setup", "completions", "--source");
			FileUtils.writeShellBlock(Shell.BASHRC, "aws-sso-cli completions", completions);
		}
	}

	public static void installConfigFile(Path configFile) {
		FileUtils.copy(configFile, AWS_SSO_DIR.resolve("config.yaml"));
	}

	public static void configProfiles(String... profiles) throws IOException {
		try (Step step = Step.start("AWS SSO CLI: config profiles")) {

			Path AWS_CONFIG = AWS_DIR.resolve("config");
			if (Files.exists(AWS_CONFIG)) {
				Files.move(
						AWS_CONFIG,
						AWS_DIR.resolve("config.bak.%s".formatted(LocalDateTime.now().format(BACKUP_DATETIME_FORMATTER)))
				);
			}
			for (String profile: profiles) {
				Shell.user("aws-sso", "login", "-S", profile);
			}

			Shell.user("aws-sso", "setup", "profiles", "--force");
		}
	}

}

==> evolver-script-java-0.2.0-sources.jar: fi/evolver/script/app/AwsSsoCli.java <==
package fi.evolver.script.app;

import java.io.IOException;
import java.net.URI;
import java.nio.file.Files;
import java.nio.file.Path;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;

import fi.evolver.script.FileUtils;
import fi.evolver.script.Shell;
import fi.evolver.script.Step;
import fi.evolver.script.system.Architecture;

public class AwsSsoCli {

	private static final URI AMD64_URL = URI.create("https://github.com/synfinatic/aws-sso-cli/releases/download/v2.0.0-beta4/aws-sso-cli_2.0.0-beta4-1_amd64.deb");
	private static final URI ARM64_URL = URI.create("https://github.com/synfinatic/aws-sso-cli/releases/download/v2.0.0-beta4/aws-sso-cli_2.0.0-beta4-1_arm64.deb");

	private static final Path AWS_DIR = Shell.HOME.resolve(".aws");
	private static final Path AWS_SSO_DIR = Shell.HOME.resolve(".aws-sso");

	private static final DateTimeFormatter BACKUP_DATETIME_FORMATTER = DateTimeFormatter.ofPattern("yyyyMMdd-HHmmss");

	public static void install() {
		try (Step step = Step.start("AWS SSO CLI: install")) {
			switch (Architecture.validated()) {
				case AMD64 -> Apt.installFromUrl(AMD64_URL);
				case ARM64 -> Apt.installFromUrl(ARM64_URL);
			}
		}
	}

	public static void installConfigFile(Path configFile) {
		FileUtils.copy(configFile, AWS_SSO_DIR.resolve("config.yaml"));
	}

	public static void configProfiles(String... profiles) throws IOException {
		try (Step step = Step.start("AWS SSO CLI: config profiles")) {

			Path AWS_CONFIG = AWS_DIR.resolve("config");
			if (Files.exists(AWS_CONFIG)) {
				Files.move(
						AWS_CONFIG,
						AWS_DIR.resolve("config.bak.%s".formatted(LocalDateTime.now().format(BACKUP_DATETIME_FORMATTER)))
				);
			}
			for (String profile: profiles) {
				Shell.user("aws-sso", "login", "-S", profile);
			}

			Shell.user("aws-sso", "setup", "profiles", "--force");
		}
	}

	/**
	 * Configures bash completion. This is non-interactive only if a config file can be found.
	 * @see #installConfigFile(Path)
	 */
	public static void configCompletions() {
		try (Step step = Step.start("AWS SSO CLI: config completions")) {
			String completions = Shell.user("aws-sso", "setup", "completions", "--source");
			FileUtils.writeShellBlock(Shell.BASHRC, "aws-sso-cli completions", completions);
		}
	}


}
